==> chromium-45.0.2432.0.tar.xz: chromium-45.0.2432.0/content/child/web_memory_allocator_dump_impl.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CONTENT_CHILD_WEB_MEMORY_ALLOCATOR_DUMP_IMPL_H_
#define CONTENT_CHILD_WEB_MEMORY_ALLOCATOR_DUMP_IMPL_H_

#include "base/memory/scoped_vector.h"
#include "third_party/WebKit/public/platform/WebMemoryAllocatorDump.h"

namespace base {
namespace trace_event {
class MemoryAllocatorDump;
}  // namespace base
}  // namespace trace_event

namespace content {

// Implements the blink::WebMemoryAllocatorDump interface by means of proxying
// the Add*() calls to the underlying base::trace_event::MemoryAllocatorDump
// instance.
class WebMemoryAllocatorDumpImpl : public blink::WebMemoryAllocatorDump {
 public:
  explicit WebMemoryAllocatorDumpImpl(
      base::trace_event::MemoryAllocatorDump* memory_allocator_dump);
  virtual ~WebMemoryAllocatorDumpImpl();

  // blink::WebMemoryAllocatorDump implementation.
  virtual void AddScalar(const char* name,
                         const char* units,
                         uint64 value);
  virtual void AddScalarF(const char* name,
                          const char* units,
                          double value);
  virtual void AddString(const char* name,
                         const char* units,
                         const blink::WebString& value);

 private:
  base::trace_event::MemoryAllocatorDump* memory_allocator_dump_;  // Not owned.

  DISALLOW_COPY_AND_ASSIGN(WebMemoryAllocatorDumpImpl);
};

}  // namespace content

#endif  // CONTENT_CHILD_WEB_MEMORY_ALLOCATOR_DUMP_IMPL_H_

==> chromium-48.0.2532.0.tar.xz: chromium-48.0.2532.0/content/child/web_memory_allocator_dump_impl.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CONTENT_CHILD_WEB_MEMORY_ALLOCATOR_DUMP_IMPL_H_
#define CONTENT_CHILD_WEB_MEMORY_ALLOCATOR_DUMP_IMPL_H_

#include "third_party/WebKit/public/platform/WebMemoryAllocatorDump.h"

namespace base {
namespace trace_event {
class MemoryAllocatorDump;
}  // namespace base
}  // namespace trace_event

namespace content {

// Implements the blink::WebMemoryAllocatorDump interface by means of proxying
// the Add*() calls to the underlying base::trace_event::MemoryAllocatorDump
// instance.
class WebMemoryAllocatorDumpImpl : public blink::WebMemoryAllocatorDump {
 public:
  explicit WebMemoryAllocatorDumpImpl(
      base::trace_event::MemoryAllocatorDump* memory_allocator_dump);
  ~WebMemoryAllocatorDumpImpl() override;

  // blink::WebMemoryAllocatorDump implementation.
  void AddScalar(const char* name, const char* units, uint64 value) override;
  void AddScalarF(const char* name, const char* units, double value) override;
  void AddString(const char* name,
                 const char* units,
                 const blink::WebString& value) override;

  blink::WebMemoryAllocatorDumpGuid guid() const override;

 private:
  base::trace_event::MemoryAllocatorDump* memory_allocator_dump_;  // Not owned.
  blink::WebMemoryAllocatorDumpGuid guid_;

  DISALLOW_COPY_AND_ASSIGN(WebMemoryAllocatorDumpImpl);
};

}  // namespace content

#endif  // CONTENT_CHILD_WEB_MEMORY_ALLOCATOR_DUMP_IMPL_H_
